/*
 * tabbase.h
 *
 * Copyright (C) 2009-2011 Christoph Pfister <christophpfister@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef TABBASE_H
#define TABBASE_H

#include <QWidget>
#include "mediawidget.h"

class TabBase : public QWidget
{
public:
	TabBase() { }
	~TabBase() { }

	virtual void activate() = 0;
	virtual	void toggleDisplayMode(MediaWidget::DisplayMode) {};
	virtual void mouse_move(int, int) {};
};

#endif /* TABBASE_H */
